import { createRoot } from 'react-dom/client';
import { App } from './App';
import React from 'react';

export class ReactRenderer {
  component: any;
  element: HTMLElement;
  ref: React.RefObject<any>;
  props: any;
  root: any;
  constructor(component: any, { props, className }: any) {
    this.component = component;
    const el = document.createElement('div');
    this.element = el;
    this.ref = React.createRef();
    this.props = {
      ...props,
      ref: this.ref,
    };
    el.className = className;
    this.root = createRoot(this.element);
    this.render();
  }

  updateProps(props: any) {
    this.props = {
      ...this.props,
      ...props,
    };
    this.render();
  }

  render() {
    this.root.render(React.createElement(this.component, this.props));
  }

  destroy() {
    this.root.unmount();
  }
}

export default ReactRenderer;

export const bootstrap = (el: HTMLElement | string) => {
  // createRoot(document.getElementById('ai-root')!).render(<App />);
  const root = typeof el === 'string' ? document.querySelector(el) : el;
  if (root) {
    const renderer = new ReactRenderer(App, {
      props: {},
      className: 'resources-root w-full h-full',
    });
    if (window.context) {
      window.context.resourcesApp = renderer;
    } else {
      window.context = {
        resourcesApp: renderer,
      };
    }
    root.appendChild(renderer.element);
  }
};
